PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Units.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Typedefs | Functions
Units.hpp File Reference
`#include <iostream>`

Go to the source code of this file.

## Data Structures
class | Length< T, M1, Q1 >

## Typedefs
using | Meters = Length<double, 1.0, 1.0>
using | Micrometers = Length<double, 1.0, 1000000.0>
using | FMicrometers = Length<float, 1.0, 1000000.0>
using | Nanometers = Length<double, 1.0, 1000000000.0>

## Functions
template<typename T, double M1, double Q1>
std::ostream & | operator<< (std::ostream &os, const Length< T, M1, Q1 > &l)

## Typedef Documentation

## ◆ FMicrometers

using FMicrometers = Length<float, 1.0, 1000000.0>

## ◆ Meters

using Meters = Length<double, 1.0, 1.0>

## ◆ Micrometers

using Micrometers = Length<double, 1.0, 1000000.0>

## ◆ Nanometers

using Nanometers = Length<double, 1.0, 1000000000.0>

## Function Documentation

## ◆ operator<<()

template<typename T, double M1, double Q1>

std::ostream & operator<< | ( | std::ostream & | os,
|  | const Length< T, M1, Q1 > & | l )
| inline